@@ -5,6 +5,6 @@ from findatapy.market.datavendor import DataVendor
 # don't include DataVendorBBG, in case users haven't installed blpapi
 # from findatapy.market.datavendorbbg import DataVendorBBG
 from findatapy.market.ioengine import IOEngine, SpeedCache
-from findatapy.market.market import Market, FXVolFactory, FXCrossFactory, FXConv
+from findatapy.market.market import Market, FXVolFactory, FXCrossFactory, FXConv, RatesFactory
 from findatapy.market.marketdatagenerator import MarketDataGenerator
 from findatapy.market.marketdatarequest import MarketDataRequest
