@@ -1,7 +1,7 @@
 __author__ = 'saeedamen'
 
 from findatapy.timeseries.timezone import Timezone
-from findatapy.timeseries.filter import Calendar
+from findatapy.timeseries.calendar import Calendar
 from findatapy.timeseries.filter import Filter
 from findatapy.timeseries.calculations import Calculations
 from findatapy.timeseries.dataquality import DataQuality
