@@ -1,7 +1,7 @@
 __author__ = 'shihhau'  # Shih-Hau Tan
 
 #
-# Copyright 2018 Cuemacro
+# Copyright 2016-2020 Cuemacro
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
 # License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
@@ -24,25 +24,27 @@ if __name__ == '__main__':
 
     market = Market(market_data_generator=MarketDataGenerator())
 
-    # choose run_example   (0 = all examples)
-    # example 1: bitcoincharts
-    # example 2: poloniex (needs to be fixed)
-    # example 3: binance
-    # example 4: bitfinex
-    # example 5: gdax
-    # example 6: kraken
-    # check findatapy/conf/time_series_tickers_list.csv for all possible tickers
+    # Choose run_example   (0 = all examples)
+    # Example 1: bitcoincharts
+    # Example 2: poloniex (needs to be fixed)
+    # Example 3: binance
+    # Example 4: bitfinex
+    # Example 5: gdax
+    # Example 6: kraken
+    #
+    # Check findatapy/conf/time_series_tickers_list.csv for all possible tickers
     # Note we use XBT instead of BTC.  Same for XET (ETH) and XLC (LTC).
-
+    #
+    # Note: there will generally be a limit of how many data points you can pull in one call, so you might
+    # have to choose smaller time periods
 
     run_example = 0
 
     if run_example == 1 or run_example == 0:
-        ### download data from bitcoincharts ###
+        ### Download data from bitcoincharts ###
         # fields contains ['close','volume']
         # return tick data
 
-
         md_request = MarketDataRequest(start_date='11 Nov 2015', finish_date='02 Feb 2018', cut='LOC',
                                        freq='tick', data_source='bitcoincharts', category='crypto',
                                        fields=['close', 'volume'], tickers=['XBTUSD_itbit'])
@@ -53,11 +55,11 @@ if __name__ == '__main__':
 
 
     if run_example == 2 or run_example == 0:
-        ### download data from poloniex ###
-        # freq : daily or intraday.  intraday - return 5 minutes data.
+        ### Download data from poloniex ###
+        # freq : daily or intraday, where intraday - returns 5 minutes data.
         # fields contains ['close','high','low','open','quote-volume','volume','weighted-average']
 
-        md_request = MarketDataRequest(start_date='18 Feb 2017', finish_date='20 Feb 2018', cut='LOC',
+        md_request = MarketDataRequest(start_date='18 Feb 2017', finish_date='20 Feb 2017', cut='LOC',
                                        freq='intraday', data_source='poloniex', category='crypto',
                                        fields=['close','volume','weighted-average'],
                                        tickers=['STRXBT'])
@@ -102,12 +104,12 @@ if __name__ == '__main__':
 
 
     if run_example == 5 or run_example == 0:
-        ### download data from gdax ###
+        ### Download data from gdax (now called coinbase pro) ###
         # freq: daily or intraday.  intraday - 1 minute data
         # fields contain ['low','high','open','close','volume']
         # Note it may take a while due to the limit of numbers per second calling the API
 
-        md_request = MarketDataRequest(start_date='01 Jan 2018', finish_date='01 Feb 2018', cut='LOC',
+        md_request = MarketDataRequest(start_date='01 Jan 2018 00:00', finish_date='01 Jan 2018 01:50', cut='LOC',
                                        freq='intraday', data_source='gdax', category='crypto',
                                        fields=['close','volume','low','high'],
                                        tickers=['XBTUSD'])
@@ -117,12 +119,13 @@ if __name__ == '__main__':
         print(df.tail(5))
 
     if run_example == 6:
-        ### download data from kraken ###
+        ### Download data from kraken ###
         # freq: tick (all trade data)
         # fields contain ['close','volume','buy-sell','market-limit']
         # buy-sell : 1 means buy, and -1 means sell
         # market-limit: 1 means market, and -1 means limit
-        # Note it may take a while due to the limit of numbers per second calling the API
+
+        # Note it may take a while due to the limit of numbers per second for calling the API
 
         md_request = MarketDataRequest(start_date='19 Feb 2018', finish_date='20 Feb 2018', cut='LOC',
                                        freq='tick', data_source='kraken', category='crypto',
